@@ -21,13 +21,11 @@
 
 #include <KCModule>
 #include <KViewStateMaintainer>
-namespace Akonadi
-{
+namespace Akonadi {
 class ETMViewStateSaver;
 }
 
-namespace PimCommon
-{
+namespace PimCommon {
 class CheckedCollectionWidget;
 }
 
@@ -38,9 +36,9 @@ class KCMKNotesSummary : public KCModule
 public:
     explicit KCMKNotesSummary(QWidget *parent = nullptr);
 
-    void load() Q_DECL_OVERRIDE;
-    void save() Q_DECL_OVERRIDE;
-    void defaults() Q_DECL_OVERRIDE;
+    void load() override;
+    void save() override;
+    void defaults() override;
 
 private Q_SLOTS:
     void modified();
