@@ -36,18 +36,15 @@ class KNotesWidget;
 class QAction;
 class KToggleAction;
 
-namespace KDNSSD
-{
+namespace KDNSSD {
 class PublicService;
 }
-namespace Akonadi
-{
+namespace Akonadi {
 class ChangeRecorder;
 class Collection;
 class ETMViewStateSaver;
 }
-namespace NoteShared
-{
+namespace NoteShared {
 class NotesChangeRecorder;
 class NotesAkonadiTreeModel;
 }
@@ -61,11 +58,10 @@ public:
     explicit KNotesPart(QObject *parent = nullptr);
     ~KNotesPart();
 
-    bool openFile() Q_DECL_OVERRIDE;
+    bool openFile() override;
 
 public Q_SLOTS:
-    void newNote(const QString &name = QString(),
-                 const QString &text = QString());
+    void newNote(const QString &name = QString(), const QString &text = QString());
     void newNoteFromClipboard(const QString &name = QString());
     QStringList notesList() const;
 
